@@ -5,6 +5,7 @@ import org.ovirt.engine.core.compat.Guid;
 public class ClusterParametersBase extends ActionParametersBase {
     private static final long serialVersionUID = -9133528679053901135L;
     private Guid clusterId;
+    private boolean force;
 
     public ClusterParametersBase(Guid clusterId) {
         this.clusterId = clusterId;
@@ -16,4 +17,12 @@ public class ClusterParametersBase extends ActionParametersBase {
 
     public ClusterParametersBase() {
     }
+
+    public boolean isForce() {
+        return force;
+    }
+
+    public void setForce(boolean force) {
+        this.force = force;
+    }
 }
