@@ -1,16 +1,16 @@
 package org.ovirt.engine.core.common.businessentities.network;
 
 import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 
 import java.util.Arrays;
 import java.util.List;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class DnsResolverConfigurationTest {
     @Test
-    public void testToString() throws Exception {
+    public void testToString() {
         List<NameServer> nameServers =
                 Arrays.asList(new NameServer("192.168.1.1"), new NameServer("192.168.1.2"));
 
