@@ -89,7 +89,6 @@ public class BackendInstanceTypeResource
     }
 
     protected InstanceType deprecatedPopulate(InstanceType model, org.ovirt.engine.core.common.businessentities.InstanceType entity) {
-        MemoryPolicyHelper.setupMemoryBalloon(model, this);
         return model;
     }
 
@@ -151,10 +150,6 @@ public class BackendInstanceTypeResource
 
             DisplayHelper.setGraphicsToParams(incoming.getDisplay(), updateParams);
 
-            if (incoming.isSetMemoryPolicy() && incoming.getMemoryPolicy().isSetBallooning()) {
-                updateParams.setBalloonEnabled(incoming.getMemoryPolicy().isBallooning());
-            }
-
             return getMapper(modelType, UpdateVmTemplateParameters.class).map(incoming, updateParams);
         }
     }
