@@ -7,7 +7,6 @@ import java.util.List;
 import java.util.Map;
 
 import com.google.gwt.core.client.Scheduler;
-import com.google.gwt.core.client.Scheduler.ScheduledCommand;
 import com.google.inject.Inject;
 
 /**
@@ -54,12 +53,7 @@ public class OperationProcessor {
         if (scheduler == null) {
             scheduler = Scheduler.get();
         }
-        scheduler.scheduleDeferred(new ScheduledCommand() {
-            @Override
-            public void execute() {
-                processAvailableOperations(manager);
-            }
-        });
+        scheduler.scheduleDeferred(() -> processAvailableOperations(manager));
     }
 
     /**
@@ -254,33 +248,4 @@ public class OperationProcessor {
     public void logoutUser(final UserCallback<?> callback) {
         communicationProvider.logout(callback);
     }
-
-    /**
-     * Default store where the caller doesn't care about the result.
-     * @param key The key
-     * @param value The value to store.
-     */
-    public void storeInHttpSession(final String key, final String value) {
-        storeInHttpSession(key, value, new StorageCallback() {
-
-            @Override
-            public void onSuccess(String result) {
-                // Do nothing
-            }
-
-            @Override
-            public void onFailure(Throwable caught) {
-                //Do nothing
-            }
-
-        });
-    }
-
-    public void storeInHttpSession(final String key, final String value, final StorageCallback callback) {
-        communicationProvider.storeInHttpSession(key, value, callback);
-    }
-
-    public void retrieveFromHttpSession(final String key, final StorageCallback callback) {
-        communicationProvider.retrieveFromHttpSession(key, callback);
-    }
 }
