@@ -1,15 +1,21 @@
 package org.ovirt.engine.ui.common.widget.table;
 
 import org.gwtbootstrap3.client.ui.Container;
+import org.ovirt.engine.ui.common.CommonApplicationConstants;
+import org.ovirt.engine.ui.common.gin.AssetProvider;
 import org.ovirt.engine.ui.common.idhandler.WithElementId;
 import org.ovirt.engine.ui.common.system.ClientStorage;
 import org.ovirt.engine.ui.common.uicommon.model.SearchableTableModelProvider;
+import org.ovirt.engine.ui.common.widget.Kebab;
 import org.ovirt.engine.ui.common.widget.PaginationControl;
+import org.ovirt.engine.ui.common.widget.action.ActionAnchorListItem;
+import org.ovirt.engine.ui.common.widget.action.ActionButton;
 import org.ovirt.engine.ui.common.widget.refresh.AbstractRefreshManager;
 import org.ovirt.engine.ui.common.widget.refresh.RefreshPanel;
 import org.ovirt.engine.ui.common.widget.refresh.SimpleRefreshManager;
 
 import com.google.gwt.core.client.GWT;
+import com.google.gwt.event.dom.client.ClickEvent;
 import com.google.gwt.event.shared.EventBus;
 import com.google.gwt.uibinder.client.UiBinder;
 import com.google.gwt.uibinder.client.UiField;
@@ -25,6 +31,8 @@ public class SimpleActionTable<E, T> extends AbstractActionTable<E, T> {
         WidgetUiBinder uiBinder = GWT.create(WidgetUiBinder.class);
     }
 
+    private static final CommonApplicationConstants constants = AssetProvider.getConstants();
+
     @UiField
     Container tableOverheadContainer;
 
@@ -35,6 +43,9 @@ public class SimpleActionTable<E, T> extends AbstractActionTable<E, T> {
     @WithElementId
     public RefreshPanel refreshPanel;
 
+    @UiField
+    Kebab actionKebab;
+
     @UiField
     PaginationControl paginationControl;
 
@@ -73,6 +84,32 @@ public class SimpleActionTable<E, T> extends AbstractActionTable<E, T> {
             dataProvider.onManualRefresh();
             setLoadingState(LoadingState.LOADING);
         });
+
+        createActionKebab();
+        showActionKebab();
+    }
+
+    private void createActionKebab() {
+        ActionButton changeBtn = new ActionAnchorListItem(constants.changeColumnsVisibilityOrder());
+        changeBtn.addClickHandler(event -> showColumnModificationDialog(event));
+        actionKebab.addMenuItem(changeBtn);
+
+        ActionButton resetBtn = new ActionAnchorListItem(constants.resetGridSettings());
+        resetBtn.addClickHandler(event -> resetGridSettings());
+        actionKebab.addMenuItem(resetBtn);
+    }
+
+    private void showColumnModificationDialog(ClickEvent event) {
+        closeOtherPopups();
+        table.ensureContextMenuHandler().onContextMenu(event.getNativeEvent());
+    }
+
+    private void resetGridSettings() {
+        table.resetGridSettings();
+    }
+
+    public void showActionKebab() {
+        actionKebab.setVisible(true);
     }
 
     public FlowPanel getOuterWidget() {
