@@ -3,12 +3,11 @@ package org.ovirt.engine.ui.uicommonweb.models.vms;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.RunVmOnceParams;
-import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.businessentities.VDS;
 import org.ovirt.engine.core.common.businessentities.VDSStatus;
 import org.ovirt.engine.core.common.businessentities.VM;
-import org.ovirt.engine.ui.frontend.AsyncCallback;
 import org.ovirt.engine.ui.frontend.Frontend;
 import org.ovirt.engine.ui.uicommonweb.ICommandTarget;
 import org.ovirt.engine.ui.uicommonweb.dataprovider.AsyncDataProvider;
@@ -39,24 +38,21 @@ public class WebadminRunOnceModel extends RunOnceModel {
     private void loadHosts() {
         // append just active hosts
         AsyncDataProvider.getInstance().getHostListByCluster(new AsyncQuery<>(
-                new AsyncCallback<List<VDS>>() {
-            @Override
-            public void onSuccess(List<VDS> hosts) {
-                final List<VDS> activeHosts = new ArrayList<>();
-                for (VDS host : hosts) {
-                    if (VDSStatus.Up.equals(host.getStatus())) {
-                        activeHosts.add(host);
+                hosts -> {
+                    final List<VDS> activeHosts = new ArrayList<>();
+                    for (VDS host : hosts) {
+                        if (VDSStatus.Up.equals(host.getStatus())) {
+                            activeHosts.add(host);
+                        }
                     }
-                }
 
-                getDefaultHost().setItems(activeHosts);
+                    getDefaultHost().setItems(activeHosts);
 
-                // hide host tab when no active host is available
-                if (activeHosts.isEmpty()) {
-                    setIsHostTabVisible(false);
-                }
-            }
-        }), vm.getClusterName());
+                    // hide host tab when no active host is available
+                    if (activeHosts.isEmpty()) {
+                        setIsHostTabVisible(false);
+                    }
+                }), vm.getClusterName());
     }
 
     @Override
@@ -76,7 +72,7 @@ public class WebadminRunOnceModel extends RunOnceModel {
 
     @Override
     protected void onRunOnce() {
-        Frontend.getInstance().runAction(VdcActionType.RunVmOnce, createRunVmOnceParams(), null, this);
+        Frontend.getInstance().runAction(ActionType.RunVmOnce, createRunVmOnceParams(), null, this);
         commandTarget.executeCommand(runOnceCommand);
     }
 }
